#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 28 16:02:11 2020

@author: tladd
"""

import pickle
import numpy as np
import matplotlib.pyplot as plt


Pes = [100, 1, 0.01]
Pe2 = [1000, 300, 100, 30, 10, 3, 1, 0.3, 0.1, 0.03, 0.01, 0.003, 0.001]
M   = 32
N   = 128
Nm  = 8
m   = np.arange(-M, 2)

#Plot set up
plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 22
plt.rcParams['legend.fontsize'] = 16
plt.rcParams['xtick.labelsize'] = 18
plt.rcParams['ytick.labelsize'] = 18

plt.figure(1,figsize=(12,6))
ax1=plt.subplot2grid((1,2),(0,0),colspan=1,rowspan=1)
ax1.spines['top'].set_visible(False)
ax1.spines['right'].set_visible(False)
ax1.set_xlabel(r'$1-t/t_0$', labelpad=2)
ax1.set_ylabel(r'$A/A_0$')
ax1.set_prop_cycle(color=['k', 'r', 'b', 'm', 'c'])
ax1.set_xlim(0.001,1)
ax1.set_ylim(0.0001,1)
ax1.text(10**(-0.4),10**(-3.4),'(a)')

ax2=plt.subplot2grid((1,2),(0,1),colspan=1,rowspan=1)
ax2.spines['top'].set_visible(False)
ax2.spines['right'].set_visible(False)
ax2.set_xlabel(r'$Pe$', labelpad=1)
ax2.set_ylabel(r'$t_0/t_0^0$')
ax2.set_prop_cycle(color=['k'])
ax2.set_xlim(0.001,1000)
ax2.set_ylim(0,1)
ax2.text(10**(2.2),0.15,'(b)')

for Pe in Pes:
    name = 'Pe='+str(Pe)+'-M='+str(M)+'-N='+str(N)+'-Nm='+str(Nm)
    t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))
    nt = len(t)

# Calculate moments in z space
    A = (m*y*y).sum(1)
    label = r'$Pe=$'+str(Pe)
    ax1.loglog(1-t/t[-1], A, label=label)
    
ax1.loglog(1-t/t[-1],1-t/t[-1],'k--', label='Linear')
ax1.loglog(1-t/t[-1],(1-t/t[-1])**(4/3),'k:', label='$-4/3$')
ax1.legend(loc='upper left', labelspacing=0.2)

t00 = np.sqrt(np.array(Pe2)*np.pi**3/36)
t0  = []
for Pe in Pe2:
    name = 'Pe='+str(Pe)+'-M='+str(M)+'-N='+str(N)+'-Nm='+str(Nm)
    t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))
    t0.append(t[-1])
pe = np.arange(1e-3,1,1e-3)
f  = (1-2*np.euler_gamma-2*np.log(pe/4))*pe/4*np.sqrt(36/np.pi**3/pe)
f0 =  (-2*np.euler_gamma-2*np.log(pe/4))*pe/4*np.sqrt(36/np.pi**3/pe)
ax2.semilogx(Pe2, t0/t00, 'ko', clip_on=False)
ax2.semilogx([1,1100], [1,1] , 'k', clip_on=False, label=r'$Pe \rightarrow \infty$')
ax2.semilogx(pe, f , 'k--', label=r'$Pe \rightarrow 0$')
ax2.semilogx(pe, f0 , 'k:', label=r'$Pe \rightarrow 0 \approx $')
ax2.legend(loc='upper left', labelspacing=0.2)
plt.savefig('../fig10.pdf')
