#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 28 16:02:11 2020

@author: tladd
"""

import pickle
import numpy as np
import matplotlib.pyplot as plt


Pe1 = [100, 10, 1, 0.1, 0.01]
Pe2 = [1000, 300, 100, 30, 10, 3, 1, 0.3, 0.1, 0.03, 0.01, 0.003, 0.001]
M   = 32
N   = 128
Nm  = 8
m   = np.arange(-M, 2)

#Plot set up
plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 22
plt.rcParams['legend.fontsize'] = 16
plt.rcParams['xtick.labelsize'] = 18
plt.rcParams['ytick.labelsize'] = 18

plt.figure(1,figsize=(12,6))
ax1=plt.subplot2grid((1,2),(0,0),colspan=1,rowspan=1)
ax1.spines['top'].set_visible(False)
ax1.spines['right'].set_visible(False)
ax1.set_xlabel(r'$t/t_0$', labelpad=2)
ax1.set_ylabel(r'$\Delta x$')
ax1.set_prop_cycle(color=['k', 'm', 'r', 'c', 'b'])
ax1.set_xlim(0,1)
ax1.set_ylim(0,0.8)
ax1.text(0.85,0.15,'(a)')

ax2=plt.subplot2grid((1,2),(0,1),colspan=1,rowspan=1)
ax2.spines['top'].set_visible(False)
ax2.spines['right'].set_visible(False)
ax2.set_xlabel(r'$Pe$', labelpad=2)
ax2.set_ylabel(r'$\Delta x(t_0)$')
ax2.set_prop_cycle(color=['k'])
ax2.set_xlim(0.001,1000)
ax2.set_ylim(0,0.8)
ax2.text(10**(2.2),0.15,'(b)')

X0 = [];
for Pe in Pe2:
    name = 'Pe='+str(Pe)+'-M='+str(M)+'-N='+str(N)+'-Nm='+str(Nm)
    t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))
    nt = len(t)

# Calculate moments in z space
    A = (m*y*y).sum(1)
    X = np.zeros(len(t))
    for mp in m:
        for mpp in m:
            if  mp+mpp in m:                            # 1/2 * 1/2 * 2
                X += 0.5*(mp+mpp)*y.T[mp+M]*y.T[mpp+M]*y.T[mp+mpp+M]
            if  mp-mpp in m:
                X += 0.5*(mp-mpp)*y.T[mp+M]*y.T[mpp+M]*y.T[mp-mpp+M]
            if -mp+mpp in m:
                X += 0.5*(-mp+mpp)*y.T[mp+M]*y.T[mpp+M]*y.T[-mp+mpp+M]
            if -mp-mpp in m:
                X += 0.5*(-mp-mpp)*y.T[mp+M]*y.T[mpp+M]*y.T[-mp-mpp+M]
    X /= A*2
    X0.append(X[-1])
    if Pe in Pe1:
        label = '$Pe=$'+str(Pe)
        ax1.plot(t/t[-1], X, label=label, clip_on=False)
ax1.legend(loc='upper left', labelspacing=0.2)

ax2.semilogx(Pe2, X0, 'ko', clip_on=False)
pe = np.arange(1e-3,1,1e-3)
f  = -pe/4*(1+2*np.euler_gamma+2*np.log(pe/4))
f0 = -pe/4*(2+2*np.euler_gamma+2*np.log(pe/4))
ax2.semilogx([10,1100], [0.8,0.8] , 'k', clip_on=False, label=r'$Pe \rightarrow \infty$')
ax2.semilogx(pe, f, 'k--', label=r'$Pe \rightarrow 0$')
ax2.semilogx(pe, f0, 'k:', label=r'$Pe \rightarrow 0 \approx$')
ax2.legend(loc='upper left', labelspacing=0.2)
plt.savefig('../fig11.pdf')
