#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 28 16:02:11 2020

@author: tladd
"""

import pickle
import numpy as np
import matplotlib.pyplot as plt


Pe1 = [100, 10, 1, 0.1]
Pe2 = [1000, 300, 100, 30, 10, 3, 1, 0.3, 0.1, 0.03, 0.01, 0.003, 0.001]
M   = 32
N   = 128
Nm  = 8

#Plot set up
plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 22
plt.rcParams['legend.fontsize'] = 18
plt.rcParams['xtick.labelsize'] = 18
plt.rcParams['ytick.labelsize'] = 18

plt.figure(1,figsize=(12,6))
ax1=plt.subplot2grid((1,2),(0,0),colspan=1,rowspan=1)
ax1.spines['top'].set_visible(False)
ax1.spines['right'].set_visible(False)
ax1.set_xlabel(r'$t/t_0$', labelpad = 2)
ax1.set_ylabel(r'$A_R$')
ax1.set_prop_cycle(color=['k', 'm', 'r', 'b'])
ax1.set_xlim(0,1)
ax1.set_ylim(0,1)
ax1.text(0.85,0.15,'(a)')

ax2=plt.subplot2grid((1,2),(0,1),colspan=1,rowspan=1)
ax2.spines['top'].set_visible(False)
ax2.spines['right'].set_visible(False)
ax2.set_xlabel(r'$Pe$', labelpad = 2)
ax2.set_ylabel(r'$A_R(t_0)$')
ax2.set_prop_cycle(color=['k'])
ax2.set_xlim(0.001,1000)
ax2.set_ylim(0,1)
ax2.text(10**(2.2),0.15,'(b)')

W1 = []
for Pe in Pe2:
    name = 'Pe='+str(Pe)+'-M='+str(M)+'-N='+str(N)+'-Nm='+str(Nm)
    t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))
    nt = len(t)

# Calculate points in z space
    m = np.arange(-M, 2)
    n = np.ones(len(m))
    n[-2::-2] = 0
    A = (m*y*y).sum(1)
    X = (n*y).sum(1)
    W = A/X**2
    if (Pe > 1):
        W1.append(W[-1])
    else:
        W1.append(W[-2])
    if Pe in Pe1:
        label = '$Pe=$'+str(Pe)
        ax1.plot(t[0:-1]/t[-1], W[0:-1], label=label)
ax1.legend(loc='lower left')

ax2.semilogx(Pe2, W1, 'ko', clip_on=False)
plt.savefig('../fig12.pdf')
