#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 28 16:02:11 2020

@author: tladd
"""

import pickle
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.axes_grid1.inset_locator import inset_axes

Pe  = 1000
M   = 32
N   = 128
Nm  = 8
Nt  = 2048
m   = np.arange(-M, 2)
times = [0.1, 0.3, 0.5, 0.7, 0.9, 0.99, 0.999, 0.9999, 1]

def zshape(t, y, R=1):
    theta = np.linspace(0, 2*np.pi, Nt)
    w = np.exp(1j*theta)
    z = 0
    for n in range(-M, 2):
        z += y[M+n]*w**n
    z -= y[-2]
    z /= y[-1]
    return np.real(z)*R, np.imag(z)

#Plot set up
plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 14
plt.rcParams['legend.fontsize'] = 18
plt.rcParams['xtick.labelsize'] = 18
plt.rcParams['ytick.labelsize'] = 18

name = 'Pe='+str(Pe)+'-M='+str(M)+'-N='+str(N)+'-Nm='+str(Nm)
t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))
nt = len(t)

m = np.arange(-M, 2)
n = np.ones(len(m))
n[-2::-2] = 0

#plots
plt.figure(figsize=(10,10))
ax  = [0]*9
ax2 = [0]*3
xl  = [[1.25,1.3], [1.45, 1.50], [1.70,1.75]]
bxx = [1.085, 1.09, 1.2]

for n in range(9):
    time = times[n]
    tn = np.where(t/t[-1] >= time)[0][0]
    if time == 0:
        yt = y[tn]
    else:
        w  = (t[tn]-time*t[-1])/(t[tn]-t[tn-1])
        yt = w*y[tn-1] + (1-w)*y[tn]
    
    i = n//3;  j = n%3
    ax[n]=plt.subplot2grid((3,3),(i,j),colspan=1,rowspan=1, aspect='equal', adjustable='box')
    ax[n].spines['top'].set_visible(False)
    ax[n].spines['right'].set_visible(False)
    ax[n].plot(*zshape(tn, yt), 'r', linewidth=1.5, clip_on=False)
    if i == 1:
        ax2[j] = inset_axes(ax[n], width = 0.8, height = 0.8, bbox_to_anchor=(bxx[j],0.904), bbox_transform=ax[n].transAxes)
        ax2[j].plot(*zshape(tn, yt), 'b', linewidth=1.5)
        ax2[j].tick_params(labelleft=False, labelbottom=False)
        ax2[j].axis("off")
        ax2[j].set_xlim(xl[j][0], xl[j][1])
        ax2[j].set_ylim(-0.025,0.025)
        
    ax[n].set_xticks([-2,-1,0,1,2])
    ax[n].set_yticks([-1,0,1])
    ax[n].set_xlim(-2,2)
    ax[n].set_ylim(-1.5,1)
    if i < 2:
        ax[n].set_xticklabels([])
    if j > 0:
        ax[n].set_yticklabels([])
    ax[n].text(-1.6,-1.35, r'$\delta t/t_0 = ${:.1e}'.format(1-time)+r',  $a_1 = ${:.2e}'.format(y[tn,-1]))

plt.tight_layout()
plt.savefig('../fig13.pdf')
