#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 28 16:02:11 2020

@author: lyu
"""

import pickle
import numpy as np
import matplotlib.pyplot as plt

plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 18
plt.rcParams['legend.fontsize'] = 14
plt.rcParams['xtick.labelsize'] = 16
plt.rcParams['ytick.labelsize'] = 16

Pe   = 250
M    = 128
name  = 'Pe='+str(Pe)+'-M='+str(M)+'-High'
t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))

# Calculate moments in z space
m   = np.arange(-M, 2)
A = (m*y*y).sum(1)
X = np.zeros(len(t))
m = np.arange(-2,2)
for mp in m:
     for mpp in m:
         if mp+mpp in m:
             X += (mp+mpp)*y.T[mp+M]*y.T[mpp+M]*y.T[mp+mpp+M]
X /= A*2
      
# Expt
com0 = 516
R    = 310
t0   = 57.3
f    = open('Xb.dat', 'r').read().split()
tar  = np.array(f[0::2], dtype=float)/t0
area = np.array(f[1::2], dtype=float)
f    = open('COMb.dat', 'r').read().split()
tcom = np.array(f[0::2], dtype=float)/t0
com  = (com0 - np.array(f[1::2], dtype=float))/R

# Plot panel b
plt.clf()
plt.figure(1,figsize=(8,6))
plt.plot(t/t[-1], A, 'k', label=r'$A/A_0$')
plt.plot(t/t[-1], y[:,-1]**2, 'k--', label=r'$a_1^2$')
plt.plot(tar/tar[-1], area, 'k.', markevery=25, label='Experiment', clip_On=False)
plt.plot(t/t[-1], X, 'r', label=r'$\Delta x$')
plt.plot(t/t[-1], y[:,-2], 'r--', label=r'$a_0$')
plt.plot(tcom/tcom[-1], com, 'r.', markevery=3, label='Experiment', clip_On=False)
plt.xlim(0,1)
plt.ylim(0,1)
plt.xlabel(r'$t/t_0$', labelpad=-1)
plt.ylabel(r'$A/A_0 ~ \Delta x$')
plt.legend(bbox_to_anchor=(0.8, 1), loc='upper right', borderaxespad=0.5)

plt.savefig('../fig4.pdf')
