#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Nov  4 13:31:11 2019

@author: lyu
"""

import json
import numpy as np
import matplotlib.pyplot as plt
from scipy.spatial import ConvexHull

plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 16
plt.rcParams['legend.fontsize'] = 14
plt.rcParams['xtick.labelsize'] = 14
plt.rcParams['ytick.labelsize'] = 14

name1 = '2DdissolFoamPDt10Dt1C0100X250Pe250'
name2 = 'conformal_100X250_Pe250_M50_N64_Tscale0.10019'
name3 = '2DdissolFoamDt20Dt1C0100X250Pe250'
name4 = 'conformal_100X250_Pe250_M50_N64_Tscale0.08849'
name5 = '2DdissolFoamDt20Dt1Cfinite100X250Pe250'
name6 = 'conformal_100X250_Pe250_M50_N64_Tscale0.07704'
shft1 = [-5.0,-12.5]
scal1 = 0.1
shft2 = [0,0]
scal2 = 1


with open('../data/points-' + name1 + '.json', 'r') as points1File:
    allPoints1 = json.load(points1File)
with open('../data/points-' + name2 + '.json', 'r') as points2File:
    allPoints2 = json.load(points2File)
with open('../data/points-' + name3 + '.json', 'r') as points3File:
    allPoints3 = json.load(points3File)
with open('../data/points-' + name4 + '.json', 'r') as points4File:
    allPoints4 = json.load(points4File)
with open('../data/points-' + name5 + '.json', 'r') as points5File:
    allPoints5 = json.load(points5File)
with open('../data/points-' + name6 + '.json', 'r') as points6File:
    allPoints6 = json.load(points6File)

A1 = [];  A3 = [];  A5 = []    
for time in [40,80,120]:
    points1 = np.array(allPoints1[time], float)*scal1
    hull    = ConvexHull(points1, float)
    A1.append(hull.volume/np.pi)
    points3 = np.array(allPoints3[time], float)*scal1
    hull    = ConvexHull(points3, float)
    A3.append(hull.volume/np.pi)
    points5 = np.array(allPoints5[time], float)*scal1
    hull    = ConvexHull(points5, float)
    A5.append(hull.volume/np.pi)
 
points11 = np.array(allPoints1[40],  float)*scal1 + shft1
points21 = np.array(allPoints2[40],  float)*scal2 + shft2
points12 = np.array(allPoints1[80],  float)*scal1 + shft1
points22 = np.array(allPoints2[80],  float)*scal2 + shft2
points13 = np.array(allPoints1[120], float)*scal1 + shft1
points23 = np.array(allPoints2[120], float)*scal2 + shft2

points31 = np.array(allPoints3[40],  float)*scal1 + shft1+[0.019,0]
points41 = np.array(allPoints4[40],  float)*scal2 + shft2
points32 = np.array(allPoints3[80],  float)*scal1 + shft1+[0.042,0]
points42 = np.array(allPoints4[80],  float)*scal2 + shft2
points33 = np.array(allPoints3[120], float)*scal1 + shft1+[0.075,0]
points43 = np.array(allPoints4[120], float)*scal2 + shft2

points51 = np.array(allPoints5[40],  float)*scal1 + shft1+[0.030,0]
points61 = np.array(allPoints6[40],  float)*scal2 + shft2
points52 = np.array(allPoints5[80],  float)*scal1 + shft1+[0.061,0]
points62 = np.array(allPoints6[80],  float)*scal2 + shft2
points53 = np.array(allPoints5[120], float)*scal1 + shft1+[0.120,0]
points63 = np.array(allPoints6[120], float)*scal2 + shft2

#plots
plt.figure(1, figsize=(10,10))

ax1=plt.subplot2grid((3,3),(0,0),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax1.spines['top'].set_visible(False)
ax1.spines['right'].set_visible(False)
ax1.plot(points11.T[0], points11.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax1.plot(points21.T[0], points21.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax1.set_xticks([-1,-0.5,0,0.5,1])
ax1.set_yticks([-1,-0.5,0,0.5,1])
ax1.set_xticklabels([])
ax1.set_xlim(-1,1)
ax1.set_ylim(-1,1)
ax1.text(0.25,-0.95,'$A/A_0 = 0.653$', fontsize=14)

ax2=plt.subplot2grid((3,3),(0,1),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax2.spines['top'].set_visible(False)
ax2.spines['right'].set_visible(False)
ax2.plot(points12.T[0], points12.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax2.plot(points22.T[0], points22.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax2.set_xticks([-1,-0.5,0,0.5,1])
ax2.set_yticks([-1,-0.5,0,0.5,1])
ax2.set_xticklabels([])
ax2.set_yticklabels([])
ax2.set_xlim(-1,1)
ax2.set_ylim(-1,1)
ax2.text(0.25,-0.95,'$A/A_0 = 0.347$', fontsize=14)
ax2.text(-0.83,0.8, r'Potential flow: $Da_\mathrm{II} \rightarrow \infty$')

ax3=plt.subplot2grid((3,3),(0,2),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax3.spines['top'].set_visible(False)
ax3.spines['right'].set_visible(False)
ax3.plot(points13.T[0], points13.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax3.plot(points23.T[0], points23.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax3.set_xticks([-1,-0.5,0,0.5,1])
ax3.set_yticks([-1,-0.5,0,0.5,1])
ax3.set_xticklabels([])
ax3.set_yticklabels([])
ax3.set_xlim(-1,1)
ax3.set_ylim(-1,1)
ax3.text(0.8,0.8, '(a)')
ax3.text(0.25,-0.95,'$A/A_0 = 0.100$', fontsize=14)

ax4=plt.subplot2grid((3,3),(1,0),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax4.spines['top'].set_visible(False)
ax4.spines['right'].set_visible(False)
ax4.plot(points31.T[0], points31.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax4.plot(points41.T[0], points41.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax4.set_xticks([-1,-0.5,0,0.5,1])
ax4.set_yticks([-1,-0.5,0,0.5,1])
ax4.set_xticklabels([])
ax4.set_xlim(-1,1)
ax4.set_ylim(-1,1)
ax4.text(0.25,-0.95,'$A/A_0 = 0.689$', fontsize=14)

ax5=plt.subplot2grid((3,3),(1,1),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax5.spines['top'].set_visible(False)
ax5.spines['right'].set_visible(False)
ax5.plot(points32.T[0], points32.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax5.plot(points42.T[0], points42.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax5.set_xticks([-1,-0.5,0,0.5,1])
ax5.set_yticks([-1,-0.5,0,0.5,1])
ax5.set_xticklabels([])
ax5.set_yticklabels([])
ax5.set_xlim(-1,1)
ax5.set_ylim(-1,1)
ax5.text(-0.83,0.8, r'Stokes flow: $Da_\mathrm{II} \rightarrow \infty$')
ax5.text(0.25,-0.95,'$A/A_0 = 0.412$', fontsize=14)

ax6=plt.subplot2grid((3,3),(1,2),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax6.spines['top'].set_visible(False)
ax6.spines['right'].set_visible(False)
ax6.plot(points33.T[0], points33.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax6.plot(points43.T[0], points43.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax6.set_xticks([-1,-0.5,0,0.5,1])
ax6.set_yticks([-1,-0.5,0,0.5,1])
ax6.set_xticklabels([])
ax6.set_yticklabels([])
ax6.text(0.8,0.8,'(b)')
ax6.set_xlim(-1,1)
ax6.set_ylim(-1,1)
ax6.text(0.25,-0.95,'$A/A_0 = 0.179$', fontsize=14)

ax7=plt.subplot2grid((3,3),(2,0),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax7.spines['top'].set_visible(False)
ax7.spines['right'].set_visible(False)
ax7.plot(points51.T[0], points51.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax7.plot(points61.T[0], points61.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax7.set_xticks([-1,-0.5,0,.5,1])
ax7.set_yticks([-1,-0.5,0,0.5,1])
ax7.set_xlim(-1,1)
ax7.set_ylim(-1,1)
ax7.text(0.25,-0.95,'$A/A_0 = 0.725$', fontsize=14)

ax8=plt.subplot2grid((3,3),(2,1),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax8.spines['top'].set_visible(False)
ax8.spines['right'].set_visible(False)
ax8.plot(points52.T[0], points52.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax8.plot(points62.T[0], points62.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax8.set_xticks([-1,-0.5,0,0.5,1])
ax8.set_yticks([-1,-0.5,0,0.5,1])
ax8.set_yticklabels([])
ax8.set_xlim(-1,1)
ax8.set_ylim(-1,1)
ax8.text(-0.83,0.8, r'Stokes flow: $Da_\mathrm{II} = 66.6$')
ax8.text(0.25,-0.95,'$A/A_0 = 0.479$', fontsize=14)

ax9=plt.subplot2grid((3,3),(2,2),colspan=1,rowspan=1, aspect='equal', adjustable='box')
ax9.spines['top'].set_visible(False)
ax9.spines['right'].set_visible(False)
ax9.plot(points53.T[0], points53.T[1], linestyle='solid',color='red' , linewidth=1.5, clip_on=False)
ax9.plot(points63.T[0], points63.T[1], linestyle='dashed',color='black' , linewidth=1.5, clip_on=False)
ax9.set_xticks([-1,-0.5,0,0.5,1])
ax9.set_yticks([-1,-0.5,0,0.5,1])
ax9.set_yticklabels([])
ax9.text(0.8,0.8,'(c)')
ax9.set_xlim(-1,1)
ax9.set_ylim(-1,1)
ax9.text(0.25,-0.95,'$A/A_0 = 0.265$', fontsize=14)

ax3.legend(labels=['Finite Volume ','Conformal'],loc='upper left',frameon=True)
plt.tight_layout()
  
plt.savefig('../fig5.pdf')
