#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 28 16:02:11 2020

@author: lyu
"""

import json
import numpy as np
import matplotlib.pyplot as plt
from scipy.spatial import ConvexHull

plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 22
plt.rcParams['legend.fontsize'] = 14
plt.rcParams['xtick.labelsize'] = 18
plt.rcParams['ytick.labelsize'] = 18

name1 = '2DdissolFoamPDt10Dt1C0100X250Pe250'
name2 = '2DdissolFoamDt20Dt1C0100X250Pe250'
name3 = '2DdissolFoamDt20Dt1Cfinite100X250Pe250'
name4 = '2DdissolFoamDt20Dt1Cfinite38X33Pe250'

scal  = 0.1
tscal = 0.1

def moments(points):                            # Calculate area and com
    a = 0; c = 0
    for v1 in range(len(points)):
        v2 = (v1+1)%len(points)
        x   = (points[v2][0]+points[v1][0])/2
        dy  =  points[v2][1]-points[v1][1]
        a  += x*dy
        c  += 0.5*x*x*dy
    return a, c
        
def match(Aref, A):                             # Match time by area
    t = []
    for n in range(len(Aref)):
        A0 = Aref[n]                            # Get area for t[n]
        tn = np.where(A0>=A)[0]                 # index of time match
        if len(tn) > 0:
            T = tn[0]
            if len(tn) > 1:                     # interpolate between points
                dt = tn[1] - tn[0]
                dA = A[tn[1]] - A[tn[0]]
                T += (A0-A[tn[0]])*dt/dA
            t.append(T)
    if A[-1] > Aref[-1]:  t.append(len(A))
    return np.array(t)

with open('../data/points-' + name1 + '.json', 'r') as points1File:
    allPoints1 = json.load(points1File)
with open('../data/points-' + name2 + '.json', 'r') as points2File:
    allPoints2 = json.load(points2File)
with open('../data/points-' + name3 + '.json', 'r') as points3File:
    allPoints3 = json.load(points3File)
with open('../data/points-' + name4 + '.json', 'r') as points4File:
    allPoints4 = json.load(points4File)
    
t1 = np.linspace(0, (len(allPoints1)-1)*tscal, len(allPoints1))
t2 = np.linspace(0, (len(allPoints2)-1)*tscal, len(allPoints2))
t3 = np.linspace(0, (len(allPoints3)-1)*tscal, len(allPoints3))
t4 = np.linspace(0, (len(allPoints4)-1)*tscal, len(allPoints4))
A1 = np.zeros(len(allPoints1))
A2 = np.zeros(len(allPoints2))
A3 = np.zeros(len(allPoints3))
A4 = np.zeros(len(allPoints4))
C1 = np.zeros(len(allPoints1))
C2 = np.zeros(len(allPoints2))
C3 = np.zeros(len(allPoints3))
C4 = np.zeros(len(allPoints4))
    
# Calculate area and shift
for time in range(len(t1)):
    points1 = np.array(allPoints1[time], float)*scal
    hull1   = ConvexHull(points1, float)   # Get points from hull
    points1 = hull1.points[hull1.vertices]
    a, c    = moments(points1)
    A1[time]= a/np.pi
    C1[time]= c/a
    
for time in range(len(t2)):
    points2 = np.array(allPoints2[time], float)*scal
    hull2   = ConvexHull(points2, float)
    points2 = hull2.points[hull2.vertices]
    a, c    = moments(points2)
    A2[time]= a/np.pi
    C2[time]= c/a
    
for time in range(len(t3)):
    points3 = np.array(allPoints3[time], float)*scal
    hull3   = ConvexHull(points3, float)
    points3 = hull3.points[hull3.vertices]
    a, c    = moments(points3)
    A3[time]= a/np.pi
    C3[time]= c/a
    
for time in range(len(t4)):
    points4  = np.array(allPoints4[time], float)*scal
    hull4   = ConvexHull(points4, float)
    points4 = hull4.points[hull4.vertices]
    a, c    = moments(points4)
    A4[time]= a/np.pi
    C4[time]= c/a
      
# Expt
com0 = 516
R    = 310
t0   = 57.3
f    = open('Xb.dat', 'r').read().split()
tar  = np.array(f[0::2], dtype=float)/t0
area = np.array(f[1::2], dtype=float)
f    = open('COMb.dat', 'r').read().split()
tcom = np.array(f[0::2], dtype=float)/t0
com  = (com0 - np.array(f[1::2], dtype=float))/R

# Plot panel b
plt.figure(1,figsize=(12,6))
ax2=plt.subplot2grid((1,2),(0,1),colspan=1,rowspan=1)
ax2.spines['top'].set_visible(False)
ax2.spines['right'].set_visible(False)
ax2.plot(t1, C1-C1[0], 'r', label=r'Potential: $Da_\mathrm{II} \rightarrow \infty$')
ax2.plot(t2, C2-C2[0], 'b', label=r'Stokes: $Da_\mathrm{II} \rightarrow \infty$')
ax2.plot(t3, C3-C3[0], 'm', label=r'Stokes: $Da_\mathrm{II} =\, 66.7$')
ax2.plot(t4, C4-C4[0], 'k', label=r'Stokes: $Da_\mathrm{II} =\, 66.7\, (38 \times 33)$')
ax2.plot(tcom, com, 'k.', markevery=3, label='Experiment')
ax2.text(16,0.04,'(b)')
ax2.set_xlim(0,18)
ax2.set_ylim(0,0.8)
ax2.set_xlabel(r'$t$')
ax2.set_ylabel(r'$\Delta x$')
ax2.legend(loc='upper left')

# Match areas
t1 = match(A1, A1)*tscal
t2 = match(A1, A2)*tscal
t3 = match(A1, A3)*tscal
t4 = match(A1, A4)*tscal
tA = match(A1, area)
tA = tA*17.45/tA[-1]

#Plot
ax1=plt.subplot2grid((1,2),(0,0),colspan=1,rowspan=1)
ax1.set_xlabel(r'$t$')
ax1.set_ylabel(r'$t_C$')
ax1.spines['top'].set_visible(False)
ax1.spines['right'].set_visible(False)
ax1.plot(t1, t1,'r')
ax1.plot(t2, t1,'b')
ax1.plot(t3, t1,'m')
ax1.plot(t4, t1,'k')
ax1.plot(tA, t1,'k.', markevery=3)
ax1.text(16,1,'(a)')
ax1.set_xlim(0,18)
ax1.set_ylim(0,15)

plt.tight_layout()
plt.savefig('../fig6.pdf')
