# -*- coding: utf-8 -*-
"""
Created on Thu Mar 29 17:09:31 2018

@author: tladd
"""

import numpy as np
import matplotlib.pyplot as plt
import pickle

plt.rcParams['mathtext.fontset'] = 'stix'
plt.rcParams['font.family'] = 'STIXGeneral'
plt.rcParams['font.size'] = 16
plt.rcParams['legend.fontsize'] = 14
plt.rcParams['xtick.labelsize'] = 14
plt.rcParams['ytick.labelsize'] = 14

Pe   = 250
M    = 128

name  = 'Pe='+str(Pe)+'-M='+str(M)+'-High'
t, y = pickle.load(open('../data/'+name+'.pickle', 'rb'))

# Calculate leading and trailing edge velocities
m = np.linspace(-M,1,M+2)
S0p = (y).sum(axis=1)
S0m = ((-1)**m*y).sum(axis=1)
S1p = (y*m).sum(axis=1)
S1m = ((-1)**m*y*m).sum(axis=1)
S2p = (y*m*m).sum(axis=1)
S2m = ((-1)**m*y*m*m).sum(axis=1)
Cp  =  S2p/S1p**2
Cm  = -S2m/S1m**2
U0m = (S0m[1:]-S0m[0:-1])/(t[1:]-t[0:-1])
U0p = (S0p[1:]-S0p[0:-1])/(t[1:]-t[0:-1])
tpm = (t[1:]+t[0:-1])/2

# Plot leading & trailing edge velocities
Um0 = 2*np.sqrt(1/(Pe*np.pi))
plt.figure(3)
plt.clf()
plt.plot(tpm/t[-1], U0m, 'r',  label=r'$\dot{z}_b^-$')
plt.plot(tpm/t[-1], U0p, 'b', label=r'$\dot{z}_b^+$')
plt.plot(t[0:-1]/t[-1],  -Um0*np.sqrt(-S2m[0:-1])/S1m[0:-1], 'k--', label=r'$2(Pe\, \pi)^{-1/2}C_b^-$')
plt.xlim(0,1)
plt.ylim(-0.3,0.5)
plt.xlabel(r'$t/t_0$')
plt.ylabel(r'$\dot z_b$')

plt.legend(loc='upper left')
plt.tick_params(axis='both')
    
plt.show()
plt.savefig('../fig8.pdf')
